@@ -3,7 +3,7 @@
 use strict;
 use FindBin;
 use File::Spec::Functions ':ALL';
-use HTTP::Tiny;
+use LWP::Simple qw(getstore);
 use ExtUtils::Command;
 
 chdir(catdir($FindBin::Bin, updir())) or die "Failed to change to the dist root";
@@ -28,30 +28,26 @@ my $version_as_num = sprintf( q{%u%02u%02u%02u}, @version_parts );
 my $version_dotty = join '.', ($version_parts[3] ? @version_parts : @version_parts[0..2]);
 my $is_pre_30704_style = ($version_as_num < 3070400);
 my $version_for_url = $is_pre_30704_style ? $version_dotty : $version_as_num;
-my $year = "";
-if ($version_as_num >= 3080800) {
-  $year = "2015/";
-} elsif ($version_as_num >= 3080300) {
-  $year = "2014/";
-} elsif ($version_as_num >= 3071600) {
-  $year = "2013/";
-}
 
-my $url_to_download = qq{http://www.sqlite.org/${year}sqlite-}
+
+my $url_to_download = q{http://www.sqlite.org/sqlite-}
     . ($is_pre_30704_style ? q{amalgamation} : q{autoconf})
     . qq{-$version_for_url.tar.gz};
 print("downloading $url_to_download\n");
-my $rv = HTTP::Tiny->new->mirror(
+my $rv = getstore(
 	$url_to_download, 
 	"sqlite.tar.gz",
 );
-die "Failed to download" if !$rv->{success};
+die "Failed to download" if $rv != 200;
 print("done\n");
 
 rm_rf('sqlite') || rm_rf("sqlite-$version_dotty") || rm_rf("sqlite-amalgamation-$version_dotty");
 xsystem("tar zxvf sqlite.tar.gz");
-chdir("sqlite") || chdir("sqlite-$version_dotty") || chdir("sqlite-amalgamation-$version_dotty") || chdir("sqlite-autoconf-$version") || chdir("sqlite-autoconf-$version_as_num")
-|| die "SQLite directory not found.";
+chdir("sqlite") || chdir("sqlite-$version_dotty") || chdir("sqlite-amalgamation-$version_dotty") || chdir("sqlite-autoconf-$version")
+|| die "SQLite directory not found.  getsqlite.pl needs fixing to work for SQLite 3.7.5+,"
+    . " but meanwhile have a look at its source after line 48 and copy the primary files"
+    . " from the unpacked tarball over their counterparts in the root DBD::SQLite"
+    . " dir before you 'make': sqlite3.c, sqlite3.h, sqlite3ext.h, fts3_tokenizer.h";
 
 
 
